@@ -38,10 +38,6 @@ struct libvchan {
 int libvchan__check_domain_alive(PXENCONTROL_CONTEXT xc_handle, int dom);
 void _Log(XENCONTROL_LOG_LEVEL logLevel, LPCSTR function, PWCHAR format, ...);
 
-#ifdef __MINGW32__
-#define Log(level, msg, ...) _Log(level, __FUNCTION__, L"(%p) " L##msg L"\n", ctrl, ##__VA_ARGS__)
-#else
 #define Log(level, msg, ...) _Log(level, __FUNCTION__, L"(%p) " L##msg L"\n", ctrl, __VA_ARGS__)
-#endif
 
 #endif
